# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restore_plan_run import RestorePlanRun


class TestRestorePlanRun(unittest.TestCase):
    """RestorePlanRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RestorePlanRun:
        """Test RestorePlanRun
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RestorePlanRun`
        """
        model = RestorePlanRun()
        if include_optional:
            return RestorePlanRun(
                id = '',
                task_id = '',
                snapshot_id = '',
                agent_id = '',
                programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_config = '',
                plan_id = '',
                plan_type = '',
                status = 'finished',
                restore_summary = cybee_sdk.api.models.restore_summary.RestoreSummary(
                    id = '', 
                    seconds_elapsed = 0.0, 
                    total_files = 0.0, 
                    files_restored = 0.0, 
                    files_skipped = 0.0, 
                    total_bytes = 0.0, 
                    bytes_restored = 0.0, 
                    bytes_skipped = 0.0, ),
                errors = [
                    ''
                    ]
            )
        else:
            return RestorePlanRun(
                id = '',
                agent_id = '',
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_id = '',
                plan_type = '',
        )
        """

    def testRestorePlanRun(self):
        """Test RestorePlanRun"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
