# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan


class TestPageImageRestorePlan(unittest.TestCase):
    """PageImageRestorePlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageImageRestorePlan:
        """Test PageImageRestorePlan
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageImageRestorePlan`
        """
        model = PageImageRestorePlan()
        if include_optional:
            return PageImageRestorePlan(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.image_restore_plan.ImageRestorePlan(
                        id = '', 
                        name = '', 
                        description = '', 
                        repo_id = '', 
                        config = cybee_sdk.api.models.restic_restore.ResticRestore(
                            global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                                cache_dir = '', 
                                limit_download = 0.0, 
                                limit_upload = 0.0, ), 
                            exclude = [
                                ''
                                ], 
                            include = [
                                ''
                                ], 
                            iexclude = [
                                ''
                                ], 
                            iinclude = [
                                ''
                                ], 
                            host = '', 
                            path = '', 
                            tag = [
                                ''
                                ], 
                            sparse = True, 
                            target = '', 
                            verify = True, 
                            snapshot_id = '', ), 
                        schedule_enabled = True, 
                        schedule_configs = [
                            ''
                            ], 
                        last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        affected_agents = [
                            ''
                            ], 
                        extension = cybee_sdk.api.models.image_restore_plan_extension.ImageRestorePlanExtension(
                            partitions = {
                                'key' : [
                                    56
                                    ]
                                }, ), 
                        pre_script = null, 
                        post_script = null, )
                    ]
            )
        else:
            return PageImageRestorePlan(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.image_restore_plan.ImageRestorePlan(
                        id = '', 
                        name = '', 
                        description = '', 
                        repo_id = '', 
                        config = cybee_sdk.api.models.restic_restore.ResticRestore(
                            global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                                cache_dir = '', 
                                limit_download = 0.0, 
                                limit_upload = 0.0, ), 
                            exclude = [
                                ''
                                ], 
                            include = [
                                ''
                                ], 
                            iexclude = [
                                ''
                                ], 
                            iinclude = [
                                ''
                                ], 
                            host = '', 
                            path = '', 
                            tag = [
                                ''
                                ], 
                            sparse = True, 
                            target = '', 
                            verify = True, 
                            snapshot_id = '', ), 
                        schedule_enabled = True, 
                        schedule_configs = [
                            ''
                            ], 
                        last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                            created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        affected_agents = [
                            ''
                            ], 
                        extension = cybee_sdk.api.models.image_restore_plan_extension.ImageRestorePlanExtension(
                            partitions = {
                                'key' : [
                                    56
                                    ]
                                }, ), 
                        pre_script = null, 
                        post_script = null, )
                    ],
        )
        """

    def testPageImageRestorePlan(self):
        """Test PageImageRestorePlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
