# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_notification_filter_input import BackupNotificationFilterInput


class TestBackupNotificationFilterInput(unittest.TestCase):
    """BackupNotificationFilterInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupNotificationFilterInput:
        """Test BackupNotificationFilterInput
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupNotificationFilterInput`
        """
        model = BackupNotificationFilterInput()
        if include_optional:
            return BackupNotificationFilterInput(
                template_id = '',
                success = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], ),
                failed = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], ),
                finished = cybee_sdk.api.models.common_notify_filter.CommonNotifyFilter(
                    template_id = '', 
                    filter = [
                        '0'
                        ], )
            )
        else:
            return BackupNotificationFilterInput(
        )
        """

    def testBackupNotificationFilterInput(self):
        """Test BackupNotificationFilterInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
