# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class UnregisteredAgentInfo(BaseModel):
    """
    UnregisteredAgentInfo
    """  # noqa: E501

    id: UUID
    host_name: StrictStr
    domain_name: Optional[StrictStr] = None
    machine_id: StrictStr
    os_family: Optional[StrictStr] = None
    os_details: Optional[StrictStr] = None
    version: Optional[StrictStr] = None
    last_seen: datetime
    __properties: ClassVar[List[str]] = [
        "id",
        "host_name",
        "domain_name",
        "machine_id",
        "os_family",
        "os_details",
        "version",
        "last_seen",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of UnregisteredAgentInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if domain_name (nullable) is None
        # and model_fields_set contains the field
        if self.domain_name is None and "domain_name" in self.model_fields_set:
            _dict["domain_name"] = None

        # set to None if os_family (nullable) is None
        # and model_fields_set contains the field
        if self.os_family is None and "os_family" in self.model_fields_set:
            _dict["os_family"] = None

        # set to None if os_details (nullable) is None
        # and model_fields_set contains the field
        if self.os_details is None and "os_details" in self.model_fields_set:
            _dict["os_details"] = None

        # set to None if version (nullable) is None
        # and model_fields_set contains the field
        if self.version is None and "version" in self.model_fields_set:
            _dict["version"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of UnregisteredAgentInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "host_name": obj.get("host_name"),
                "domain_name": obj.get("domain_name"),
                "machine_id": obj.get("machine_id"),
                "os_family": obj.get("os_family"),
                "os_details": obj.get("os_details"),
                "version": obj.get("version"),
                "last_seen": obj.get("last_seen"),
            }
        )
        return _obj
