# coding: utf-8

# flake8: noqa
"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

# import models into model package
from cybee_sdk.api.models.additional_agent_filter import AdditionalAgentFilter
from cybee_sdk.api.models.addr import Addr
from cybee_sdk.api.models.agent_info import AgentInfo
from cybee_sdk.api.models.agent_lock import AgentLock
from cybee_sdk.api.models.agent_notification_filter import AgentNotificationFilter
from cybee_sdk.api.models.agent_update import AgentUpdate
from cybee_sdk.api.models.api_key import ApiKey
from cybee_sdk.api.models.backup_error import BackupError
from cybee_sdk.api.models.backup_fatal_error import BackupFatalError
from cybee_sdk.api.models.backup_info import BackupInfo
from cybee_sdk.api.models.backup_notification_filter_input import BackupNotificationFilterInput
from cybee_sdk.api.models.backup_notification_filter_output import BackupNotificationFilterOutput
from cybee_sdk.api.models.backup_plan_error import BackupPlanError
from cybee_sdk.api.models.backup_plan_run import BackupPlanRun
from cybee_sdk.api.models.backup_status import BackupStatus
from cybee_sdk.api.models.backup_summary import BackupSummary
from cybee_sdk.api.models.backup_verbose_status import BackupVerboseStatus
from cybee_sdk.api.models.channel import Channel
from cybee_sdk.api.models.channel_create import ChannelCreate
from cybee_sdk.api.models.channel_type import ChannelType
from cybee_sdk.api.models.common_notify_filter import CommonNotifyFilter
from cybee_sdk.api.models.cores_group import CoresGroup
from cybee_sdk.api.models.create_scheduling import CreateScheduling
from cybee_sdk.api.models.cron_calendar import CronCalendar
from cybee_sdk.api.models.dns import Dns
from cybee_sdk.api.models.drive_type import DriveType
from cybee_sdk.api.models.exclude_larger_than import ExcludeLargerThan
from cybee_sdk.api.models.exclude_larger_than1 import ExcludeLargerThan1
from cybee_sdk.api.models.file_backup_plan import FileBackupPlan
from cybee_sdk.api.models.file_backup_plan_create import FileBackupPlanCreate
from cybee_sdk.api.models.file_backup_plan_update import FileBackupPlanUpdate
from cybee_sdk.api.models.file_restore_plan import FileRestorePlan
from cybee_sdk.api.models.file_restore_plan_create import FileRestorePlanCreate
from cybee_sdk.api.models.file_restore_plan_update import FileRestorePlanUpdate
from cybee_sdk.api.models.filesystem import Filesystem
from cybee_sdk.api.models.generate_key_request import GenerateKeyRequest
from cybee_sdk.api.models.generated_api_key import GeneratedApiKey
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions
from cybee_sdk.api.models.http_validation_error import HTTPValidationError
from cybee_sdk.api.models.historical_machine import HistoricalMachine
from cybee_sdk.api.models.ip_version import IPVersion
from cybee_sdk.api.models.iface import Iface
from cybee_sdk.api.models.image_backup_plan import ImageBackupPlan
from cybee_sdk.api.models.image_backup_plan_create import ImageBackupPlanCreate
from cybee_sdk.api.models.image_backup_plan_extension import ImageBackupPlanExtension
from cybee_sdk.api.models.image_backup_plan_update import ImageBackupPlanUpdate
from cybee_sdk.api.models.image_restore_plan import ImageRestorePlan
from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate
from cybee_sdk.api.models.image_restore_plan_extension import ImageRestorePlanExtension
from cybee_sdk.api.models.image_restore_plan_update import ImageRestorePlanUpdate
from cybee_sdk.api.models.location_inner import LocationInner
from cybee_sdk.api.models.machine import Machine
from cybee_sdk.api.models.maintenance_status import MaintenanceStatus
from cybee_sdk.api.models.maintenance_type import MaintenanceType
from cybee_sdk.api.models.mass_storage import MassStorage
from cybee_sdk.api.models.memory import Memory
from cybee_sdk.api.models.notification_filter_input import NotificationFilterInput
from cybee_sdk.api.models.notification_filter_output import NotificationFilterOutput
from cybee_sdk.api.models.ntp import Ntp
from cybee_sdk.api.models.ntp_synchronized import NtpSynchronized
from cybee_sdk.api.models.organization import Organization
from cybee_sdk.api.models.os import Os
from cybee_sdk.api.models.page_agent_info import PageAgentInfo
from cybee_sdk.api.models.page_api_key import PageApiKey
from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError
from cybee_sdk.api.models.page_backup_plan_run import PageBackupPlanRun
from cybee_sdk.api.models.page_channel import PageChannel
from cybee_sdk.api.models.page_file_backup_plan import PageFileBackupPlan
from cybee_sdk.api.models.page_file_restore_plan import PageFileRestorePlan
from cybee_sdk.api.models.page_historical_machine import PageHistoricalMachine
from cybee_sdk.api.models.page_image_backup_plan import PageImageBackupPlan
from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan
from cybee_sdk.api.models.page_machine import PageMachine
from cybee_sdk.api.models.page_organization import PageOrganization
from cybee_sdk.api.models.page_repository import PageRepository
from cybee_sdk.api.models.page_repository_checks import PageRepositoryChecks
from cybee_sdk.api.models.page_repository_prunes import PageRepositoryPrunes
from cybee_sdk.api.models.page_repository_stats import PageRepositoryStats
from cybee_sdk.api.models.page_restore_plan_error import PageRestorePlanError
from cybee_sdk.api.models.page_restore_plan_run import PageRestorePlanRun
from cybee_sdk.api.models.page_router import PageRouter
from cybee_sdk.api.models.page_scheduling import PageScheduling
from cybee_sdk.api.models.page_storage_account import PageStorageAccount
from cybee_sdk.api.models.page_storage_destination import PageStorageDestination
from cybee_sdk.api.models.page_template import PageTemplate
from cybee_sdk.api.models.page_unregistered_agent_info import PageUnregisteredAgentInfo
from cybee_sdk.api.models.partition import Partition
from cybee_sdk.api.models.phy_cpu import PhyCpu
from cybee_sdk.api.models.phy_drive import PhyDrive
from cybee_sdk.api.models.plan_status import PlanStatus
from cybee_sdk.api.models.plan_type import PlanType
from cybee_sdk.api.models.pre_post_run_script import PrePostRunScript
from cybee_sdk.api.models.pyd_generic_message import PydGenericMessage
from cybee_sdk.api.models.pyd_message_type import PydMessageType
from cybee_sdk.api.models.repository import Repository
from cybee_sdk.api.models.repository_checks import RepositoryChecks
from cybee_sdk.api.models.repository_create import RepositoryCreate
from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance
from cybee_sdk.api.models.repository_maintenance_create_update import RepositoryMaintenanceCreateUpdate
from cybee_sdk.api.models.repository_prunes import RepositoryPrunes
from cybee_sdk.api.models.repository_stats import RepositoryStats
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum
from cybee_sdk.api.models.repository_update import RepositoryUpdate
from cybee_sdk.api.models.restic_backup_input import ResticBackupInput
from cybee_sdk.api.models.restic_backup_output import ResticBackupOutput
from cybee_sdk.api.models.restic_restore import ResticRestore
from cybee_sdk.api.models.restic_stats_mode_enum import ResticStatsModeEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum
from cybee_sdk.api.models.restoration_error import RestorationError
from cybee_sdk.api.models.restoration_info import RestorationInfo
from cybee_sdk.api.models.restoration_status import RestorationStatus
from cybee_sdk.api.models.restoration_summary import RestorationSummary
from cybee_sdk.api.models.restore_notification_filter_input import RestoreNotificationFilterInput
from cybee_sdk.api.models.restore_notification_filter_output import RestoreNotificationFilterOutput
from cybee_sdk.api.models.restore_plan_error import RestorePlanError
from cybee_sdk.api.models.restore_plan_run import RestorePlanRun
from cybee_sdk.api.models.restore_summary import RestoreSummary
from cybee_sdk.api.models.restore_verbose_status import RestoreVerboseStatus
from cybee_sdk.api.models.retention_settings import RetentionSettings
from cybee_sdk.api.models.router import Router
from cybee_sdk.api.models.router_create import RouterCreate
from cybee_sdk.api.models.router_update import RouterUpdate
from cybee_sdk.api.models.s3_provider import S3Provider
from cybee_sdk.api.models.s3_signature_version_enum import S3SignatureVersionEnum
from cybee_sdk.api.models.s3_storage_account_config import S3StorageAccountConfig
from cybee_sdk.api.models.scheduling import Scheduling
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans
from cybee_sdk.api.models.snapshot import Snapshot
from cybee_sdk.api.models.storage_account import StorageAccount
from cybee_sdk.api.models.storage_account_create import StorageAccountCreate
from cybee_sdk.api.models.storage_account_update import StorageAccountUpdate
from cybee_sdk.api.models.storage_destination import StorageDestination
from cybee_sdk.api.models.storage_destination_config import StorageDestinationConfig
from cybee_sdk.api.models.storage_destination_create import StorageDestinationCreate
from cybee_sdk.api.models.storage_destination_update import StorageDestinationUpdate
from cybee_sdk.api.models.storage_format import StorageFormat
from cybee_sdk.api.models.storage_notification_filter import StorageNotificationFilter
from cybee_sdk.api.models.template import Template
from cybee_sdk.api.models.template_create import TemplateCreate
from cybee_sdk.api.models.time_stamps import TimeStamps
from cybee_sdk.api.models.unregistered_agent_info import UnregisteredAgentInfo
from cybee_sdk.api.models.update_scheduling import UpdateScheduling
from cybee_sdk.api.models.validation_error import ValidationError
from cybee_sdk.api.models.zitadel_api_key_type import ZitadelApiKeyType
