# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance


class TestRepositoryMaintenance(unittest.TestCase):
    """RepositoryMaintenance unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RepositoryMaintenance:
        """Test RepositoryMaintenance
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RepositoryMaintenance`
        """
        model = RepositoryMaintenance()
        if include_optional:
            return RepositoryMaintenance(
                prune_schedule = '0',
                latest_prune = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                prune_job_pipeline_id = '',
                check_schedule = '',
                latest_check = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                check_job_pipeline_id = ''
            )
        else:
            return RepositoryMaintenance(
        )
        """

    def testRepositoryMaintenance(self):
        """Test RepositoryMaintenance"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
