# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.retention_settings import RetentionSettings


class TestRetentionSettings(unittest.TestCase):
    """RetentionSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RetentionSettings:
        """Test RetentionSettings
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RetentionSettings`
        """
        model = RetentionSettings()
        if include_optional:
            return RetentionSettings(
                keep_last = 0.0,
                keep_hourly = 0.0,
                keep_daily = 0.0,
                keep_weekly = 0.0,
                keep_monthly = 0.0,
                keep_yearly = 0.0,
                keep_within_as_secs = 0.0,
                keep_within_hourly_as_secs = 0.0,
                keep_within_daily_as_secs = 0.0,
                keep_within_weekly_as_secs = 0.0,
                keep_within_monthly_as_secs = 0.0,
                keep_within_yearly_as_secs = 0.0
            )
        else:
            return RetentionSettings(
        )
        """

    def testRetentionSettings(self):
        """Test RetentionSettings"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
