# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.partition import Partition


class TestPartition(unittest.TestCase):
    """Partition unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Partition:
        """Test Partition
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Partition`
        """
        model = Partition()
        if include_optional:
            return Partition(
                id = '',
                table_index = 56,
                device_path = '',
                size = 56,
                offset = 56,
                system_required = True,
                content = cybee_sdk.api.models.filesystem.Filesystem(
                    name = '', 
                    filesystem = '', 
                    mount_points = [
                        ''
                        ], 
                    total_size = 56, 
                    available_space = 56, 
                    is_root = True, )
            )
        else:
            return Partition(
                id = '',
                table_index = 56,
                device_path = '',
                size = 56,
                system_required = True,
        )
        """

    def testPartition(self):
        """Test Partition"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
