# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.agents_api import AgentsApi


class TestAgentsApi(unittest.TestCase):
    """AgentsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AgentsApi()

    def tearDown(self) -> None:
        pass

    def test_approve_agent_agent_agent_id_approve_post(self) -> None:
        """Test case for approve_agent_agent_agent_id_approve_post

        Approve Agent
        """
        pass

    def test_delete_agent_agent_agent_id_delete(self) -> None:
        """Test case for delete_agent_agent_agent_id_delete

        Delete Agent
        """
        pass

    def test_get_agent_agent_unregistered_get(self) -> None:
        """Test case for get_agent_agent_unregistered_get

        Get Agent
        """
        pass

    def test_list_agent_agent_get(self) -> None:
        """Test case for list_agent_agent_get

        List Agent
        """
        pass

    def test_lock_agent_agent_agent_id_lock_post(self) -> None:
        """Test case for lock_agent_agent_agent_id_lock_post

        Lock Agent
        """
        pass

    def test_unlock_agent_agent_agent_id_unlock_post(self) -> None:
        """Test case for unlock_agent_agent_agent_id_unlock_post

        Unlock Agent
        """
        pass

    def test_update_agent_agent_agent_id_put(self) -> None:
        """Test case for update_agent_agent_agent_id_put

        Update Agent
        """
        pass


if __name__ == "__main__":
    unittest.main()
