# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.mass_storage import MassStorage


class TestMassStorage(unittest.TestCase):
    """MassStorage unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> MassStorage:
        """Test MassStorage
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `MassStorage`
        """
        model = MassStorage()
        if include_optional:
            return MassStorage(
                storage_format = None,
                id = '',
                device_path = '',
                name = '',
                total_size = 56,
                largest_free_space = 56,
                support = cybee_sdk.api.models.phy_drive.PhyDrive(
                    size = 56, 
                    drive_type = null, 
                    name = '', ),
                content = [
                    cybee_sdk.api.models.partition.Partition(
                        id = '', 
                        table_index = 56, 
                        device_path = '', 
                        size = 56, 
                        offset = 56, 
                        system_required = True, )
                    ]
            )
        else:
            return MassStorage(
                storage_format = None,
                id = '',
                device_path = '',
                name = '',
                total_size = 56,
                largest_free_space = 56,
        )
        """

    def testMassStorage(self):
        """Test MassStorage"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
