# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restic_backup_input import ResticBackupInput


class TestResticBackupInput(unittest.TestCase):
    """ResticBackupInput unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResticBackupInput:
        """Test ResticBackupInput
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResticBackupInput`
        """
        model = ResticBackupInput()
        if include_optional:
            return ResticBackupInput(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                source_paths = [
                    ''
                    ],
                exclude = [
                    ''
                    ],
                exclude_caches = True,
                exclude_if_present = [
                    ''
                    ],
                exclude_larger_than = None,
                iexclude = [
                    ''
                    ]
            )
        else:
            return ResticBackupInput(
        )
        """

    def testResticBackupInput(self):
        """Test ResticBackupInput"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
