# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.snapshot import Snapshot


class TestSnapshot(unittest.TestCase):
    """Snapshot unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Snapshot:
        """Test Snapshot
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Snapshot`
        """
        model = Snapshot()
        if include_optional:
            return Snapshot(
                id = '',
                files_new = 0.0,
                files_changed = 0.0,
                files_unmodified = 0.0,
                dirs_new = 0.0,
                dirs_changed = 0.0,
                dirs_unmodified = 0.0,
                data_blobs = 0.0,
                tree_blobs = 0.0,
                data_added = 0.0,
                data_added_packed = 0.0,
                total_files_processed = 0.0,
                total_bytes_processed = 0.0,
                total_duration = 0.0,
                snapshot_id = '',
                backup_paths = [
                    ''
                    ]
            )
        else:
            return Snapshot(
                id = '',
        )
        """

    def testSnapshot(self):
        """Test Snapshot"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
