# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate


class TestImageRestorePlanCreate(unittest.TestCase):
    """ImageRestorePlanCreate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ImageRestorePlanCreate:
        """Test ImageRestorePlanCreate
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ImageRestorePlanCreate`
        """
        model = ImageRestorePlanCreate()
        if include_optional:
            return ImageRestorePlanCreate(
                name = '0',
                description = '0',
                repo_id = '',
                config = cybee_sdk.api.models.restic_restore.ResticRestore(
                    global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                        cache_dir = '', 
                        limit_download = 0.0, 
                        limit_upload = 0.0, ), 
                    exclude = [
                        ''
                        ], 
                    include = [
                        ''
                        ], 
                    iexclude = [
                        ''
                        ], 
                    iinclude = [
                        ''
                        ], 
                    host = '', 
                    path = '', 
                    tag = [
                        ''
                        ], 
                    sparse = True, 
                    target = '', 
                    verify = True, 
                    snapshot_id = '', ),
                schedule_enabled = True,
                schedule_configs = [
                    ''
                    ],
                affected_agents = [
                    ''
                    ],
                extension = cybee_sdk.api.models.image_backup_plan_extension.ImageBackupPlanExtension(
                    partitions = {
                        'key' : [
                            56
                            ]
                        }, ),
                pre_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, ),
                post_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, )
            )
        else:
            return ImageRestorePlanCreate(
                name = '0',
                repo_id = '',
                config = cybee_sdk.api.models.restic_restore.ResticRestore(
                    global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                        cache_dir = '', 
                        limit_download = 0.0, 
                        limit_upload = 0.0, ), 
                    exclude = [
                        ''
                        ], 
                    include = [
                        ''
                        ], 
                    iexclude = [
                        ''
                        ], 
                    iinclude = [
                        ''
                        ], 
                    host = '', 
                    path = '', 
                    tag = [
                        ''
                        ], 
                    sparse = True, 
                    target = '', 
                    verify = True, 
                    snapshot_id = '', ),
                extension = cybee_sdk.api.models.image_backup_plan_extension.ImageBackupPlanExtension(
                    partitions = {
                        'key' : [
                            56
                            ]
                        }, ),
        )
        """

    def testImageRestorePlanCreate(self):
        """Test ImageRestorePlanCreate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
