# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_plan_run import BackupPlanRun


class TestBackupPlanRun(unittest.TestCase):
    """BackupPlanRun unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupPlanRun:
        """Test BackupPlanRun
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupPlanRun`
        """
        model = BackupPlanRun()
        if include_optional:
            return BackupPlanRun(
                id = '',
                task_id = '',
                snapshot_id = '',
                agent_id = '',
                programmed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                repository_id = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                plan_config = '',
                plan_id = '',
                plan_type = '',
                status = 'finished',
                snapshots = [
                    cybee_sdk.api.models.snapshot.Snapshot(
                        id = '', 
                        files_new = 0.0, 
                        files_changed = 0.0, 
                        files_unmodified = 0.0, 
                        dirs_new = 0.0, 
                        dirs_changed = 0.0, 
                        dirs_unmodified = 0.0, 
                        data_blobs = 0.0, 
                        tree_blobs = 0.0, 
                        data_added = 0.0, 
                        data_added_packed = 0.0, 
                        total_files_processed = 0.0, 
                        total_bytes_processed = 0.0, 
                        total_duration = 0.0, 
                        snapshot_id = '', 
                        backup_paths = [
                            ''
                            ], )
                    ],
                errors = [
                    ''
                    ]
            )
        else:
            return BackupPlanRun(
                id = '',
                agent_id = '',
                repository_id = '',
                plan_id = '',
                plan_type = '',
        )
        """

    def testBackupPlanRun(self):
        """Test BackupPlanRun"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
