# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_machine import PageMachine


class TestPageMachine(unittest.TestCase):
    """PageMachine unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageMachine:
        """Test PageMachine
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageMachine`
        """
        model = PageMachine()
        if include_optional:
            return PageMachine(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.machine.Machine(
                        machine_id = '', 
                        cpus = [
                            cybee_sdk.api.models.phy_cpu.PhyCpu(
                                vendor = '', 
                                brand = '', 
                                architecture = '', 
                                cores = [
                                    cybee_sdk.api.models.cores_group.CoresGroup(
                                        variant = '', 
                                        cores_count = 56, 
                                        threads_per_core = 56, 
                                        freq = 1.337, )
                                    ], )
                            ], 
                        os = null, 
                        mass_storage = [
                            cybee_sdk.api.models.mass_storage.MassStorage(
                                storage_format = null, 
                                id = '', 
                                device_path = '', 
                                name = '', 
                                total_size = 56, 
                                largest_free_space = 56, 
                                support = null, 
                                content = [
                                    cybee_sdk.api.models.partition.Partition(
                                        id = '', 
                                        table_index = 56, 
                                        device_path = '', 
                                        size = 56, 
                                        offset = 56, 
                                        system_required = True, )
                                    ], )
                            ], 
                        filesystems = [
                            cybee_sdk.api.models.filesystem.Filesystem(
                                name = '', 
                                filesystem = '', 
                                mount_points = [
                                    ''
                                    ], 
                                total_size = 56, 
                                available_space = 56, 
                                is_root = True, )
                            ], 
                        ifaces = [
                            cybee_sdk.api.models.iface.Iface(
                                mac_address = '', 
                                ip_addresses = [
                                    cybee_sdk.api.models.addr.Addr(
                                        ip_version = 'V4', 
                                        ip = '', 
                                        broadcast = '', 
                                        netmask = '', )
                                    ], 
                                name = '', )
                            ], 
                        dns = [
                            cybee_sdk.api.models.dns.Dns(
                                hostname = '', )
                            ], 
                        ntp = null, 
                        memory = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return PageMachine(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.machine.Machine(
                        machine_id = '', 
                        cpus = [
                            cybee_sdk.api.models.phy_cpu.PhyCpu(
                                vendor = '', 
                                brand = '', 
                                architecture = '', 
                                cores = [
                                    cybee_sdk.api.models.cores_group.CoresGroup(
                                        variant = '', 
                                        cores_count = 56, 
                                        threads_per_core = 56, 
                                        freq = 1.337, )
                                    ], )
                            ], 
                        os = null, 
                        mass_storage = [
                            cybee_sdk.api.models.mass_storage.MassStorage(
                                storage_format = null, 
                                id = '', 
                                device_path = '', 
                                name = '', 
                                total_size = 56, 
                                largest_free_space = 56, 
                                support = null, 
                                content = [
                                    cybee_sdk.api.models.partition.Partition(
                                        id = '', 
                                        table_index = 56, 
                                        device_path = '', 
                                        size = 56, 
                                        offset = 56, 
                                        system_required = True, )
                                    ], )
                            ], 
                        filesystems = [
                            cybee_sdk.api.models.filesystem.Filesystem(
                                name = '', 
                                filesystem = '', 
                                mount_points = [
                                    ''
                                    ], 
                                total_size = 56, 
                                available_space = 56, 
                                is_root = True, )
                            ], 
                        ifaces = [
                            cybee_sdk.api.models.iface.Iface(
                                mac_address = '', 
                                ip_addresses = [
                                    cybee_sdk.api.models.addr.Addr(
                                        ip_version = 'V4', 
                                        ip = '', 
                                        broadcast = '', 
                                        netmask = '', )
                                    ], 
                                name = '', )
                            ], 
                        dns = [
                            cybee_sdk.api.models.dns.Dns(
                                hostname = '', )
                            ], 
                        ntp = null, 
                        memory = null, 
                        created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        changed_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testPageMachine(self):
        """Test PageMachine"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
