# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_restore_api import PlansRestoreApi


class TestPlansRestoreApi(unittest.TestCase):
    """PlansRestoreApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansRestoreApi()

    def tearDown(self) -> None:
        pass

    def test_assign_restore_plan_agent_plan_restore_plan_id_assign_agent_agent_id_post(self) -> None:
        """Test case for assign_restore_plan_agent_plan_restore_plan_id_assign_agent_agent_id_post

        Assign Restore Plan Agent
        """
        pass

    def test_assign_restore_plan_schedule_plan_restore_plan_id_assign_schedule_schedule_id_post(self) -> None:
        """Test case for assign_restore_plan_schedule_plan_restore_plan_id_assign_schedule_schedule_id_post

        Assign Restore Plan Schedule
        """
        pass

    def test_cancel_running_restore_plan_plan_restore_run_restore_plan_run_id_cancel_put(self) -> None:
        """Test case for cancel_running_restore_plan_plan_restore_run_restore_plan_run_id_cancel_put

        Cancel Running Restore Plan
        """
        pass

    def test_create_file_restore_plans_plan_restore_file_post(self) -> None:
        """Test case for create_file_restore_plans_plan_restore_file_post

        Create File Restore Plans
        """
        pass

    def test_create_image_restore_plans_plan_restore_image_post(self) -> None:
        """Test case for create_image_restore_plans_plan_restore_image_post

        Create Image Restore Plans
        """
        pass

    def test_delete_file_restore_plans_plan_restore_file_plan_id_delete(self) -> None:
        """Test case for delete_file_restore_plans_plan_restore_file_plan_id_delete

        Delete File Restore Plans
        """
        pass

    def test_delete_image_restore_plans_plan_restore_image_plan_id_delete(self) -> None:
        """Test case for delete_image_restore_plans_plan_restore_image_plan_id_delete

        Delete Image Restore Plans
        """
        pass

    def test_execute_file_restore_plan_plan_restore_file_plan_id_execute_post(self) -> None:
        """Test case for execute_file_restore_plan_plan_restore_file_plan_id_execute_post

        Execute File Restore Plan
        """
        pass

    def test_execute_image_restore_plan_plan_restore_image_plan_id_execute_post(self) -> None:
        """Test case for execute_image_restore_plan_plan_restore_image_plan_id_execute_post

        Execute Image Restore Plan
        """
        pass

    def test_get_running_plan_status_plan_restore_run_plan_run_id_status_get(self) -> None:
        """Test case for get_running_plan_status_plan_restore_run_plan_run_id_status_get

        Get Running Plan Status
        """
        pass

    def test_list_all_latest_restore_history_plan_restore_history_latest_get(self) -> None:
        """Test case for list_all_latest_restore_history_plan_restore_history_latest_get

        List All Latest Restore History
        """
        pass

    def test_list_all_restore_history_error_plan_restore_history_error_get(self) -> None:
        """Test case for list_all_restore_history_error_plan_restore_history_error_get

        List All Restore History Error
        """
        pass

    def test_list_all_restore_history_plan_restore_history_get(self) -> None:
        """Test case for list_all_restore_history_plan_restore_history_get

        List All Restore History
        """
        pass

    def test_list_file_restore_plans_plan_restore_file_get(self) -> None:
        """Test case for list_file_restore_plans_plan_restore_file_get

        List File Restore Plans
        """
        pass

    def test_list_image_restore_plans_plan_restore_image_get(self) -> None:
        """Test case for list_image_restore_plans_plan_restore_image_get

        List Image Restore Plans
        """
        pass

    def test_remove_restore_plan_agent_plan_restore_plan_id_remove_agent_agent_id_post(self) -> None:
        """Test case for remove_restore_plan_agent_plan_restore_plan_id_remove_agent_agent_id_post

        Remove Restore Plan Agent
        """
        pass

    def test_remove_restore_plan_schedule_plan_restore_plan_id_remove_schedule_schedule_id_post(self) -> None:
        """Test case for remove_restore_plan_schedule_plan_restore_plan_id_remove_schedule_schedule_id_post

        Remove Restore Plan Schedule
        """
        pass

    def test_update_file_restore_plans_plan_restore_file_plan_id_put(self) -> None:
        """Test case for update_file_restore_plans_plan_restore_file_plan_id_put

        Update File Restore Plans
        """
        pass

    def test_update_image_restore_plans_plan_restore_image_plan_id_put(self) -> None:
        """Test case for update_image_restore_plans_plan_restore_image_plan_id_put

        Update Image Restore Plans
        """
        pass


if __name__ == "__main__":
    unittest.main()
