# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.pyd_message_type import PydMessageType


class TestPydMessageType(unittest.TestCase):
    """PydMessageType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPydMessageType(self):
        """Test PydMessageType"""
        # inst = PydMessageType()


if __name__ == "__main__":
    unittest.main()
