# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.file_backup_plan import FileBackupPlan


class TestFileBackupPlan(unittest.TestCase):
    """FileBackupPlan unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FileBackupPlan:
        """Test FileBackupPlan
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `FileBackupPlan`
        """
        model = FileBackupPlan()
        if include_optional:
            return FileBackupPlan(
                id = '',
                name = '',
                description = '',
                repo_id = '',
                config = cybee_sdk.api.models.restic_backup.ResticBackup(
                    global_options = null, 
                    source_paths = [
                        ''
                        ], 
                    exclude = [
                        ''
                        ], 
                    exclude_caches = True, 
                    exclude_if_present = [
                        ''
                        ], 
                    exclude_larger_than = null, 
                    iexclude = [
                        ''
                        ], ),
                retention_settings = cybee_sdk.api.models.retention_settings.RetentionSettings(
                    keep_last = 0.0, 
                    keep_hourly = 0.0, 
                    keep_daily = 0.0, 
                    keep_weekly = 0.0, 
                    keep_monthly = 0.0, 
                    keep_yearly = 0.0, 
                    keep_within_as_secs = 0.0, 
                    keep_within_hourly_as_secs = 0.0, 
                    keep_within_daily_as_secs = 0.0, 
                    keep_within_weekly_as_secs = 0.0, 
                    keep_within_monthly_as_secs = 0.0, 
                    keep_within_yearly_as_secs = 0.0, ),
                schedule_enabled = True,
                schedule_configs = [
                    ''
                    ],
                last_executed = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                affected_agents = [
                    ''
                    ],
                pre_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, ),
                post_script = cybee_sdk.api.models.pre_post_run_script.PrePostRunScript(
                    executor = '', 
                    args = [
                        ''
                        ], 
                    envs = {
                        'key' : ''
                        }, 
                    script_path = '', 
                    script = '', 
                    abort_if_fail = True, )
            )
        else:
            return FileBackupPlan(
                id = '',
                name = '',
                repo_id = '',
                config = cybee_sdk.api.models.restic_backup.ResticBackup(
                    global_options = null, 
                    source_paths = [
                        ''
                        ], 
                    exclude = [
                        ''
                        ], 
                    exclude_caches = True, 
                    exclude_if_present = [
                        ''
                        ], 
                    exclude_larger_than = null, 
                    iexclude = [
                        ''
                        ], ),
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
        )
        """

    def testFileBackupPlan(self):
        """Test FileBackupPlan"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
