# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restic_restore import ResticRestore


class TestResticRestore(unittest.TestCase):
    """ResticRestore unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResticRestore:
        """Test ResticRestore
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `ResticRestore`
        """
        model = ResticRestore()
        if include_optional:
            return ResticRestore(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                exclude = [
                    ''
                    ],
                include = [
                    ''
                    ],
                iexclude = [
                    ''
                    ],
                iinclude = [
                    ''
                    ],
                host = '',
                path = '',
                tag = [
                    ''
                    ],
                sparse = True,
                target = '',
                verify = True,
                snapshot_id = ''
            )
        else:
            return ResticRestore(
                global_options = cybee_sdk.api.models.global_restic_options.GlobalResticOptions(
                    cache_dir = '', 
                    limit_download = 0.0, 
                    limit_upload = 0.0, ),
                target = '',
                snapshot_id = '',
        )
        """

    def testResticRestore(self):
        """Test ResticRestore"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
