# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError


class TestPageBackupPlanError(unittest.TestCase):
    """PageBackupPlanError unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PageBackupPlanError:
        """Test PageBackupPlanError
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PageBackupPlanError`
        """
        model = PageBackupPlanError()
        if include_optional:
            return PageBackupPlanError(
                page = 56,
                per_page = 56,
                total_items = 56,
                total_pages = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_error.BackupPlanError(
                        id = '', 
                        backup_run_id = '', 
                        error = { }, 
                        during = '', 
                        item = '', )
                    ]
            )
        else:
            return PageBackupPlanError(
                page = 56,
                per_page = 56,
                total_items = 56,
                items = [
                    cybee_sdk.api.models.backup_plan_error.BackupPlanError(
                        id = '', 
                        backup_run_id = '', 
                        error = { }, 
                        during = '', 
                        item = '', )
                    ],
        )
        """

    def testPageBackupPlanError(self):
        """Test PageBackupPlanError"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
