# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Repository(BaseModel):
    """
    Repository
    """  # noqa: E501

    id: UUID
    name: StrictStr
    slug: StrictStr
    description: Optional[StrictStr] = None
    status: RepositoryStatusEnum
    storage_destination_id: UUID
    created_at: datetime
    updated_at: datetime
    version: ResticVersionEnum
    __properties: ClassVar[List[str]] = [
        "id",
        "name",
        "slug",
        "description",
        "status",
        "storage_destination_id",
        "created_at",
        "updated_at",
        "version",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Repository from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict["description"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Repository from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "slug": obj.get("slug"),
                "description": obj.get("description"),
                "status": obj.get("status"),
                "storage_destination_id": obj.get("storage_destination_id"),
                "created_at": obj.get("created_at"),
                "updated_at": obj.get("updated_at"),
                "version": obj.get("version"),
            }
        )
        return _obj
