# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.notification_api import NotificationApi


class TestNotificationApi(unittest.TestCase):
    """NotificationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = NotificationApi()

    def tearDown(self) -> None:
        pass

    def test_create_channel_notification_channels_channel_type_post(self) -> None:
        """Test case for create_channel_notification_channels_channel_type_post

        Create Channel
        """
        pass

    def test_create_router_notification_routers_post(self) -> None:
        """Test case for create_router_notification_routers_post

        Create Router
        """
        pass

    def test_create_template_notification_templates_post(self) -> None:
        """Test case for create_template_notification_templates_post

        Create Template
        """
        pass

    def test_delete_channel_notification_channels_channel_id_delete(self) -> None:
        """Test case for delete_channel_notification_channels_channel_id_delete

        Delete Channel
        """
        pass

    def test_delete_router_notification_routers_router_id_delete(self) -> None:
        """Test case for delete_router_notification_routers_router_id_delete

        Delete Router
        """
        pass

    def test_delete_template_notification_templates_template_id_delete(self) -> None:
        """Test case for delete_template_notification_templates_template_id_delete

        Delete Template
        """
        pass

    def test_list_channels_notification_channels_get(self) -> None:
        """Test case for list_channels_notification_channels_get

        List Channels
        """
        pass

    def test_list_routers_notification_routers_get(self) -> None:
        """Test case for list_routers_notification_routers_get

        List Routers
        """
        pass

    def test_list_templates_notification_templates_get(self) -> None:
        """Test case for list_templates_notification_templates_get

        List Templates
        """
        pass

    def test_update_router_notification_routers_router_id_patch(self) -> None:
        """Test case for update_router_notification_routers_router_id_patch

        Update Router
        """
        pass


if __name__ == "__main__":
    unittest.main()
