# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_account_api import StorageAccountApi


class TestStorageAccountApi(unittest.TestCase):
    """StorageAccountApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageAccountApi()

    def tearDown(self) -> None:
        pass

    def test_create_storage_account_storage_storage_account_post(self) -> None:
        """Test case for create_storage_account_storage_storage_account_post

        Create Storage Account
        """
        pass

    def test_delete_storage_account_storage_storage_account_storage_account_id_delete(self) -> None:
        """Test case for delete_storage_account_storage_storage_account_storage_account_id_delete

        Delete Storage Account
        """
        pass

    def test_get_storage_account_storage_storage_account_storage_account_id_get(self) -> None:
        """Test case for get_storage_account_storage_storage_account_storage_account_id_get

        Get Storage Account
        """
        pass

    def test_list_storage_account_storage_storage_account_get(self) -> None:
        """Test case for list_storage_account_storage_storage_account_get

        List Storage Account
        """
        pass

    def test_update_storage_account_storage_storage_account_storage_account_id_put(self) -> None:
        """Test case for update_storage_account_storage_storage_account_storage_account_id_put

        Update Storage Account
        """
        pass


if __name__ == "__main__":
    unittest.main()
