# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_backup_api import PlansBackupApi


class TestPlansBackupApi(unittest.TestCase):
    """PlansBackupApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansBackupApi()

    def tearDown(self) -> None:
        pass

    def test_assign_backup_plan_agent_plan_backup_plan_id_assign_agent_agent_id_post(self) -> None:
        """Test case for assign_backup_plan_agent_plan_backup_plan_id_assign_agent_agent_id_post

        Assign Backup Plan Agent
        """
        pass

    def test_assign_backup_plan_schedule_plan_backup_plan_id_assign_schedule_schedule_id_post(self) -> None:
        """Test case for assign_backup_plan_schedule_plan_backup_plan_id_assign_schedule_schedule_id_post

        Assign Backup Plan Schedule
        """
        pass

    def test_cancel_running_backup_plan_plan_backup_run_backup_plan_run_id_cancel_put(self) -> None:
        """Test case for cancel_running_backup_plan_plan_backup_run_backup_plan_run_id_cancel_put

        Cancel Running Backup Plan
        """
        pass

    def test_create_file_backup_plans_plan_backup_file_post(self) -> None:
        """Test case for create_file_backup_plans_plan_backup_file_post

        Create File Backup Plans
        """
        pass

    def test_create_image_backup_plans_plan_backup_image_post(self) -> None:
        """Test case for create_image_backup_plans_plan_backup_image_post

        Create Image Backup Plans
        """
        pass

    def test_delete_file_backup_plans_plan_backup_file_plan_id_delete(self) -> None:
        """Test case for delete_file_backup_plans_plan_backup_file_plan_id_delete

        Delete File Backup Plans
        """
        pass

    def test_delete_image_backup_plans_plan_backup_image_plan_id_delete(self) -> None:
        """Test case for delete_image_backup_plans_plan_backup_image_plan_id_delete

        Delete Image Backup Plans
        """
        pass

    def test_execute_file_backup_plan_plan_backup_file_plan_id_execute_post(self) -> None:
        """Test case for execute_file_backup_plan_plan_backup_file_plan_id_execute_post

        Execute File Backup Plan
        """
        pass

    def test_execute_image_backup_plan_plan_backup_image_plan_id_execute_post(self) -> None:
        """Test case for execute_image_backup_plan_plan_backup_image_plan_id_execute_post

        Execute Image Backup Plan
        """
        pass

    def test_get_running_plan_status_plan_backup_run_plan_run_id_status_get(self) -> None:
        """Test case for get_running_plan_status_plan_backup_run_plan_run_id_status_get

        Get Running Plan Status
        """
        pass

    def test_list_all_backup_history_error_plan_backup_history_error_get(self) -> None:
        """Test case for list_all_backup_history_error_plan_backup_history_error_get

        List All Backup History Error
        """
        pass

    def test_list_all_backup_history_plan_backup_history_get(self) -> None:
        """Test case for list_all_backup_history_plan_backup_history_get

        List All Backup History
        """
        pass

    def test_list_all_latest_backup_history_plan_backup_history_latest_get(self) -> None:
        """Test case for list_all_latest_backup_history_plan_backup_history_latest_get

        List All Latest Backup History
        """
        pass

    def test_list_file_backup_plans_plan_backup_file_get(self) -> None:
        """Test case for list_file_backup_plans_plan_backup_file_get

        List File Backup Plans
        """
        pass

    def test_list_image_backup_plans_plan_backup_image_get(self) -> None:
        """Test case for list_image_backup_plans_plan_backup_image_get

        List Image Backup Plans
        """
        pass

    def test_remove_backup_plan_agent_plan_backup_plan_id_remove_agent_agent_id_post(self) -> None:
        """Test case for remove_backup_plan_agent_plan_backup_plan_id_remove_agent_agent_id_post

        Remove Backup Plan Agent
        """
        pass

    def test_remove_backup_plan_schedule_plan_backup_plan_id_remove_schedule_schedule_id_post(self) -> None:
        """Test case for remove_backup_plan_schedule_plan_backup_plan_id_remove_schedule_schedule_id_post

        Remove Backup Plan Schedule
        """
        pass

    def test_update_file_backup_plans_plan_backup_file_plan_id_put(self) -> None:
        """Test case for update_file_backup_plans_plan_backup_file_plan_id_put

        Update File Backup Plans
        """
        pass

    def test_update_image_backup_plans_plan_backup_image_plan_id_put(self) -> None:
        """Test case for update_image_backup_plans_plan_backup_image_plan_id_put

        Update Image Backup Plans
        """
        pass


if __name__ == "__main__":
    unittest.main()
