# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_destination_api import StorageDestinationApi


class TestStorageDestinationApi(unittest.TestCase):
    """StorageDestinationApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageDestinationApi()

    def tearDown(self) -> None:
        pass

    def test_create_storage_destination_storage_storage_destination_post(self) -> None:
        """Test case for create_storage_destination_storage_storage_destination_post

        Create Storage Destination
        """
        pass

    def test_delete_storage_destination_storage_storage_destination_storage_destination_id_delete(self) -> None:
        """Test case for delete_storage_destination_storage_storage_destination_storage_destination_id_delete

        Delete Storage Destination
        """
        pass

    def test_get_storage_destination_storage_storage_destination_storage_destination_id_get(self) -> None:
        """Test case for get_storage_destination_storage_storage_destination_storage_destination_id_get

        Get Storage Destination
        """
        pass

    def test_list_storage_destination_storage_storage_destination_get(self) -> None:
        """Test case for list_storage_destination_storage_storage_destination_get

        List Storage Destination
        """
        pass

    def test_update_storage_destination_storage_storage_destination_storage_destination_id_patch(self) -> None:
        """Test case for update_storage_destination_storage_storage_destination_storage_destination_id_patch

        Update Storage Destination
        """
        pass


if __name__ == "__main__":
    unittest.main()
