# coding: utf-8

# flake8: noqa

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "0.42.0"

# Define package exports
__all__ = [
    "AgentsApi",
    "CmdbApi",
    "IdentityApi",
    "NotificationApi",
    "PlansBackupApi",
    "PlansRestoreApi",
    "PlansScheduleApi",
    "StorageAccountApi",
    "StorageDestinationApi",
    "StorageRepositoryApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdditionalAgentFilter",
    "Addr",
    "AgentInfo",
    "AgentLock",
    "AgentNotificationFilter",
    "AgentUpdate",
    "ApiKey",
    "BackupError",
    "BackupFatalError",
    "BackupInfo",
    "BackupNotificationFilterInput",
    "BackupNotificationFilterOutput",
    "BackupPlanError",
    "BackupPlanRun",
    "BackupStatus",
    "BackupSummary",
    "BackupVerboseStatus",
    "Channel",
    "ChannelCreate",
    "ChannelType",
    "CommonNotifyFilter",
    "CoresGroup",
    "CreateScheduling",
    "CronCalendar",
    "Dns",
    "DriveType",
    "ExcludeLargerThan",
    "ExcludeLargerThan1",
    "FileBackupPlan",
    "FileBackupPlanCreate",
    "FileBackupPlanUpdate",
    "FileRestorePlan",
    "FileRestorePlanCreate",
    "FileRestorePlanUpdate",
    "Filesystem",
    "GenerateKeyRequest",
    "GeneratedApiKey",
    "GlobalResticOptions",
    "HTTPValidationError",
    "HistoricalMachine",
    "IPVersion",
    "Iface",
    "ImageBackupPlan",
    "ImageBackupPlanCreate",
    "ImageBackupPlanExtension",
    "ImageBackupPlanUpdate",
    "ImageRestorePlan",
    "ImageRestorePlanCreate",
    "ImageRestorePlanExtension",
    "ImageRestorePlanUpdate",
    "LocationInner",
    "Machine",
    "MaintenanceStatus",
    "MaintenanceType",
    "MassStorage",
    "Memory",
    "NotificationFilterInput",
    "NotificationFilterOutput",
    "Ntp",
    "NtpSynchronized",
    "Organization",
    "Os",
    "PageAgentInfo",
    "PageApiKey",
    "PageBackupPlanError",
    "PageBackupPlanRun",
    "PageChannel",
    "PageFileBackupPlan",
    "PageFileRestorePlan",
    "PageHistoricalMachine",
    "PageImageBackupPlan",
    "PageImageRestorePlan",
    "PageMachine",
    "PageOrganization",
    "PageRepository",
    "PageRepositoryChecks",
    "PageRepositoryPrunes",
    "PageRepositoryStats",
    "PageRestorePlanError",
    "PageRestorePlanRun",
    "PageRouter",
    "PageScheduling",
    "PageStorageAccount",
    "PageStorageDestination",
    "PageTemplate",
    "PageUnregisteredAgentInfo",
    "Partition",
    "PhyCpu",
    "PhyDrive",
    "PlanStatus",
    "PlanType",
    "PrePostRunScript",
    "PydGenericMessage",
    "PydMessageType",
    "Repository",
    "RepositoryChecks",
    "RepositoryCreate",
    "RepositoryMaintenance",
    "RepositoryMaintenanceCreateUpdate",
    "RepositoryPrunes",
    "RepositoryStats",
    "RepositoryStatusEnum",
    "RepositoryUpdate",
    "ResticBackupInput",
    "ResticBackupOutput",
    "ResticRestore",
    "ResticStatsModeEnum",
    "ResticVersionEnum",
    "RestorationError",
    "RestorationInfo",
    "RestorationStatus",
    "RestorationSummary",
    "RestoreNotificationFilterInput",
    "RestoreNotificationFilterOutput",
    "RestorePlanError",
    "RestorePlanRun",
    "RestoreSummary",
    "RestoreVerboseStatus",
    "RetentionSettings",
    "Router",
    "RouterCreate",
    "RouterUpdate",
    "S3Provider",
    "S3SignatureVersionEnum",
    "S3StorageAccountConfig",
    "Scheduling",
    "SchedulingLinkedPlans",
    "Snapshot",
    "StorageAccount",
    "StorageAccountCreate",
    "StorageAccountUpdate",
    "StorageDestination",
    "StorageDestinationConfig",
    "StorageDestinationCreate",
    "StorageDestinationUpdate",
    "StorageFormat",
    "StorageNotificationFilter",
    "Template",
    "TemplateCreate",
    "TimeStamps",
    "UnregisteredAgentInfo",
    "UpdateScheduling",
    "ValidationError",
    "ZitadelApiKeyType",
]

# import apis into sdk package
from cybee_sdk.api.api.agents_api import AgentsApi as AgentsApi
from cybee_sdk.api.api.cmdb_api import CmdbApi as CmdbApi
from cybee_sdk.api.api.identity_api import IdentityApi as IdentityApi
from cybee_sdk.api.api.notification_api import NotificationApi as NotificationApi
from cybee_sdk.api.api.plans_backup_api import PlansBackupApi as PlansBackupApi
from cybee_sdk.api.api.plans_restore_api import PlansRestoreApi as PlansRestoreApi
from cybee_sdk.api.api.plans_schedule_api import PlansScheduleApi as PlansScheduleApi
from cybee_sdk.api.api.storage_account_api import StorageAccountApi as StorageAccountApi
from cybee_sdk.api.api.storage_destination_api import StorageDestinationApi as StorageDestinationApi
from cybee_sdk.api.api.storage_repository_api import StorageRepositoryApi as StorageRepositoryApi

# import ApiClient
from cybee_sdk.api.api_response import ApiResponse as ApiResponse
from cybee_sdk.api.api_client import ApiClient as ApiClient
from cybee_sdk.api.configuration import Configuration as Configuration
from cybee_sdk.api.exceptions import OpenApiException as OpenApiException
from cybee_sdk.api.exceptions import ApiTypeError as ApiTypeError
from cybee_sdk.api.exceptions import ApiValueError as ApiValueError
from cybee_sdk.api.exceptions import ApiKeyError as ApiKeyError
from cybee_sdk.api.exceptions import ApiAttributeError as ApiAttributeError
from cybee_sdk.api.exceptions import ApiException as ApiException

# import models into sdk package
from cybee_sdk.api.models.additional_agent_filter import AdditionalAgentFilter as AdditionalAgentFilter
from cybee_sdk.api.models.addr import Addr as Addr
from cybee_sdk.api.models.agent_info import AgentInfo as AgentInfo
from cybee_sdk.api.models.agent_lock import AgentLock as AgentLock
from cybee_sdk.api.models.agent_notification_filter import AgentNotificationFilter as AgentNotificationFilter
from cybee_sdk.api.models.agent_update import AgentUpdate as AgentUpdate
from cybee_sdk.api.models.api_key import ApiKey as ApiKey
from cybee_sdk.api.models.backup_error import BackupError as BackupError
from cybee_sdk.api.models.backup_fatal_error import BackupFatalError as BackupFatalError
from cybee_sdk.api.models.backup_info import BackupInfo as BackupInfo
from cybee_sdk.api.models.backup_notification_filter_input import (
    BackupNotificationFilterInput as BackupNotificationFilterInput,
)
from cybee_sdk.api.models.backup_notification_filter_output import (
    BackupNotificationFilterOutput as BackupNotificationFilterOutput,
)
from cybee_sdk.api.models.backup_plan_error import BackupPlanError as BackupPlanError
from cybee_sdk.api.models.backup_plan_run import BackupPlanRun as BackupPlanRun
from cybee_sdk.api.models.backup_status import BackupStatus as BackupStatus
from cybee_sdk.api.models.backup_summary import BackupSummary as BackupSummary
from cybee_sdk.api.models.backup_verbose_status import BackupVerboseStatus as BackupVerboseStatus
from cybee_sdk.api.models.channel import Channel as Channel
from cybee_sdk.api.models.channel_create import ChannelCreate as ChannelCreate
from cybee_sdk.api.models.channel_type import ChannelType as ChannelType
from cybee_sdk.api.models.common_notify_filter import CommonNotifyFilter as CommonNotifyFilter
from cybee_sdk.api.models.cores_group import CoresGroup as CoresGroup
from cybee_sdk.api.models.create_scheduling import CreateScheduling as CreateScheduling
from cybee_sdk.api.models.cron_calendar import CronCalendar as CronCalendar
from cybee_sdk.api.models.dns import Dns as Dns
from cybee_sdk.api.models.drive_type import DriveType as DriveType
from cybee_sdk.api.models.exclude_larger_than import ExcludeLargerThan as ExcludeLargerThan
from cybee_sdk.api.models.exclude_larger_than1 import ExcludeLargerThan1 as ExcludeLargerThan1
from cybee_sdk.api.models.file_backup_plan import FileBackupPlan as FileBackupPlan
from cybee_sdk.api.models.file_backup_plan_create import FileBackupPlanCreate as FileBackupPlanCreate
from cybee_sdk.api.models.file_backup_plan_update import FileBackupPlanUpdate as FileBackupPlanUpdate
from cybee_sdk.api.models.file_restore_plan import FileRestorePlan as FileRestorePlan
from cybee_sdk.api.models.file_restore_plan_create import FileRestorePlanCreate as FileRestorePlanCreate
from cybee_sdk.api.models.file_restore_plan_update import FileRestorePlanUpdate as FileRestorePlanUpdate
from cybee_sdk.api.models.filesystem import Filesystem as Filesystem
from cybee_sdk.api.models.generate_key_request import GenerateKeyRequest as GenerateKeyRequest
from cybee_sdk.api.models.generated_api_key import GeneratedApiKey as GeneratedApiKey
from cybee_sdk.api.models.global_restic_options import GlobalResticOptions as GlobalResticOptions
from cybee_sdk.api.models.http_validation_error import HTTPValidationError as HTTPValidationError
from cybee_sdk.api.models.historical_machine import HistoricalMachine as HistoricalMachine
from cybee_sdk.api.models.ip_version import IPVersion as IPVersion
from cybee_sdk.api.models.iface import Iface as Iface
from cybee_sdk.api.models.image_backup_plan import ImageBackupPlan as ImageBackupPlan
from cybee_sdk.api.models.image_backup_plan_create import ImageBackupPlanCreate as ImageBackupPlanCreate
from cybee_sdk.api.models.image_backup_plan_extension import ImageBackupPlanExtension as ImageBackupPlanExtension
from cybee_sdk.api.models.image_backup_plan_update import ImageBackupPlanUpdate as ImageBackupPlanUpdate
from cybee_sdk.api.models.image_restore_plan import ImageRestorePlan as ImageRestorePlan
from cybee_sdk.api.models.image_restore_plan_create import ImageRestorePlanCreate as ImageRestorePlanCreate
from cybee_sdk.api.models.image_restore_plan_extension import ImageRestorePlanExtension as ImageRestorePlanExtension
from cybee_sdk.api.models.image_restore_plan_update import ImageRestorePlanUpdate as ImageRestorePlanUpdate
from cybee_sdk.api.models.location_inner import LocationInner as LocationInner
from cybee_sdk.api.models.machine import Machine as Machine
from cybee_sdk.api.models.maintenance_status import MaintenanceStatus as MaintenanceStatus
from cybee_sdk.api.models.maintenance_type import MaintenanceType as MaintenanceType
from cybee_sdk.api.models.mass_storage import MassStorage as MassStorage
from cybee_sdk.api.models.memory import Memory as Memory
from cybee_sdk.api.models.notification_filter_input import NotificationFilterInput as NotificationFilterInput
from cybee_sdk.api.models.notification_filter_output import NotificationFilterOutput as NotificationFilterOutput
from cybee_sdk.api.models.ntp import Ntp as Ntp
from cybee_sdk.api.models.ntp_synchronized import NtpSynchronized as NtpSynchronized
from cybee_sdk.api.models.organization import Organization as Organization
from cybee_sdk.api.models.os import Os as Os
from cybee_sdk.api.models.page_agent_info import PageAgentInfo as PageAgentInfo
from cybee_sdk.api.models.page_api_key import PageApiKey as PageApiKey
from cybee_sdk.api.models.page_backup_plan_error import PageBackupPlanError as PageBackupPlanError
from cybee_sdk.api.models.page_backup_plan_run import PageBackupPlanRun as PageBackupPlanRun
from cybee_sdk.api.models.page_channel import PageChannel as PageChannel
from cybee_sdk.api.models.page_file_backup_plan import PageFileBackupPlan as PageFileBackupPlan
from cybee_sdk.api.models.page_file_restore_plan import PageFileRestorePlan as PageFileRestorePlan
from cybee_sdk.api.models.page_historical_machine import PageHistoricalMachine as PageHistoricalMachine
from cybee_sdk.api.models.page_image_backup_plan import PageImageBackupPlan as PageImageBackupPlan
from cybee_sdk.api.models.page_image_restore_plan import PageImageRestorePlan as PageImageRestorePlan
from cybee_sdk.api.models.page_machine import PageMachine as PageMachine
from cybee_sdk.api.models.page_organization import PageOrganization as PageOrganization
from cybee_sdk.api.models.page_repository import PageRepository as PageRepository
from cybee_sdk.api.models.page_repository_checks import PageRepositoryChecks as PageRepositoryChecks
from cybee_sdk.api.models.page_repository_prunes import PageRepositoryPrunes as PageRepositoryPrunes
from cybee_sdk.api.models.page_repository_stats import PageRepositoryStats as PageRepositoryStats
from cybee_sdk.api.models.page_restore_plan_error import PageRestorePlanError as PageRestorePlanError
from cybee_sdk.api.models.page_restore_plan_run import PageRestorePlanRun as PageRestorePlanRun
from cybee_sdk.api.models.page_router import PageRouter as PageRouter
from cybee_sdk.api.models.page_scheduling import PageScheduling as PageScheduling
from cybee_sdk.api.models.page_storage_account import PageStorageAccount as PageStorageAccount
from cybee_sdk.api.models.page_storage_destination import PageStorageDestination as PageStorageDestination
from cybee_sdk.api.models.page_template import PageTemplate as PageTemplate
from cybee_sdk.api.models.page_unregistered_agent_info import PageUnregisteredAgentInfo as PageUnregisteredAgentInfo
from cybee_sdk.api.models.partition import Partition as Partition
from cybee_sdk.api.models.phy_cpu import PhyCpu as PhyCpu
from cybee_sdk.api.models.phy_drive import PhyDrive as PhyDrive
from cybee_sdk.api.models.plan_status import PlanStatus as PlanStatus
from cybee_sdk.api.models.plan_type import PlanType as PlanType
from cybee_sdk.api.models.pre_post_run_script import PrePostRunScript as PrePostRunScript
from cybee_sdk.api.models.pyd_generic_message import PydGenericMessage as PydGenericMessage
from cybee_sdk.api.models.pyd_message_type import PydMessageType as PydMessageType
from cybee_sdk.api.models.repository import Repository as Repository
from cybee_sdk.api.models.repository_checks import RepositoryChecks as RepositoryChecks
from cybee_sdk.api.models.repository_create import RepositoryCreate as RepositoryCreate
from cybee_sdk.api.models.repository_maintenance import RepositoryMaintenance as RepositoryMaintenance
from cybee_sdk.api.models.repository_maintenance_create_update import (
    RepositoryMaintenanceCreateUpdate as RepositoryMaintenanceCreateUpdate,
)
from cybee_sdk.api.models.repository_prunes import RepositoryPrunes as RepositoryPrunes
from cybee_sdk.api.models.repository_stats import RepositoryStats as RepositoryStats
from cybee_sdk.api.models.repository_status_enum import RepositoryStatusEnum as RepositoryStatusEnum
from cybee_sdk.api.models.repository_update import RepositoryUpdate as RepositoryUpdate
from cybee_sdk.api.models.restic_backup_input import ResticBackupInput as ResticBackupInput
from cybee_sdk.api.models.restic_backup_output import ResticBackupOutput as ResticBackupOutput
from cybee_sdk.api.models.restic_restore import ResticRestore as ResticRestore
from cybee_sdk.api.models.restic_stats_mode_enum import ResticStatsModeEnum as ResticStatsModeEnum
from cybee_sdk.api.models.restic_version_enum import ResticVersionEnum as ResticVersionEnum
from cybee_sdk.api.models.restoration_error import RestorationError as RestorationError
from cybee_sdk.api.models.restoration_info import RestorationInfo as RestorationInfo
from cybee_sdk.api.models.restoration_status import RestorationStatus as RestorationStatus
from cybee_sdk.api.models.restoration_summary import RestorationSummary as RestorationSummary
from cybee_sdk.api.models.restore_notification_filter_input import (
    RestoreNotificationFilterInput as RestoreNotificationFilterInput,
)
from cybee_sdk.api.models.restore_notification_filter_output import (
    RestoreNotificationFilterOutput as RestoreNotificationFilterOutput,
)
from cybee_sdk.api.models.restore_plan_error import RestorePlanError as RestorePlanError
from cybee_sdk.api.models.restore_plan_run import RestorePlanRun as RestorePlanRun
from cybee_sdk.api.models.restore_summary import RestoreSummary as RestoreSummary
from cybee_sdk.api.models.restore_verbose_status import RestoreVerboseStatus as RestoreVerboseStatus
from cybee_sdk.api.models.retention_settings import RetentionSettings as RetentionSettings
from cybee_sdk.api.models.router import Router as Router
from cybee_sdk.api.models.router_create import RouterCreate as RouterCreate
from cybee_sdk.api.models.router_update import RouterUpdate as RouterUpdate
from cybee_sdk.api.models.s3_provider import S3Provider as S3Provider
from cybee_sdk.api.models.s3_signature_version_enum import S3SignatureVersionEnum as S3SignatureVersionEnum
from cybee_sdk.api.models.s3_storage_account_config import S3StorageAccountConfig as S3StorageAccountConfig
from cybee_sdk.api.models.scheduling import Scheduling as Scheduling
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans as SchedulingLinkedPlans
from cybee_sdk.api.models.snapshot import Snapshot as Snapshot
from cybee_sdk.api.models.storage_account import StorageAccount as StorageAccount
from cybee_sdk.api.models.storage_account_create import StorageAccountCreate as StorageAccountCreate
from cybee_sdk.api.models.storage_account_update import StorageAccountUpdate as StorageAccountUpdate
from cybee_sdk.api.models.storage_destination import StorageDestination as StorageDestination
from cybee_sdk.api.models.storage_destination_config import StorageDestinationConfig as StorageDestinationConfig
from cybee_sdk.api.models.storage_destination_create import StorageDestinationCreate as StorageDestinationCreate
from cybee_sdk.api.models.storage_destination_update import StorageDestinationUpdate as StorageDestinationUpdate
from cybee_sdk.api.models.storage_format import StorageFormat as StorageFormat
from cybee_sdk.api.models.storage_notification_filter import StorageNotificationFilter as StorageNotificationFilter
from cybee_sdk.api.models.template import Template as Template
from cybee_sdk.api.models.template_create import TemplateCreate as TemplateCreate
from cybee_sdk.api.models.time_stamps import TimeStamps as TimeStamps
from cybee_sdk.api.models.unregistered_agent_info import UnregisteredAgentInfo as UnregisteredAgentInfo
from cybee_sdk.api.models.update_scheduling import UpdateScheduling as UpdateScheduling
from cybee_sdk.api.models.validation_error import ValidationError as ValidationError
from cybee_sdk.api.models.zitadel_api_key_type import ZitadelApiKeyType as ZitadelApiKeyType
