# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.plans_schedule_api import PlansScheduleApi


class TestPlansScheduleApi(unittest.TestCase):
    """PlansScheduleApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PlansScheduleApi()

    def tearDown(self) -> None:
        pass

    def test_create_plan_schedule_plan_schedule_schedule_post(self) -> None:
        """Test case for create_plan_schedule_plan_schedule_schedule_post

        Create Plan Schedule
        """
        pass

    def test_delete_plan_schedule_plan_schedule_schedule_schedule_id_delete(self) -> None:
        """Test case for delete_plan_schedule_plan_schedule_schedule_schedule_id_delete

        Delete Plan Schedule
        """
        pass

    def test_list_plan_schedules_plan_schedule_schedule_get(self) -> None:
        """Test case for list_plan_schedules_plan_schedule_schedule_get

        List Plan Schedules
        """
        pass

    def test_update_plan_schedule_plan_schedule_schedule_schedule_id_put(self) -> None:
        """Test case for update_plan_schedule_plan_schedule_schedule_schedule_id_put

        Update Plan Schedule
        """
        pass


if __name__ == "__main__":
    unittest.main()
