# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.phy_cpu import PhyCpu


class TestPhyCpu(unittest.TestCase):
    """PhyCpu unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PhyCpu:
        """Test PhyCpu
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `PhyCpu`
        """
        model = PhyCpu()
        if include_optional:
            return PhyCpu(
                vendor = '',
                brand = '',
                architecture = '',
                cores = [
                    cybee_sdk.api.models.cores_group.CoresGroup(
                        variant = '', 
                        cores_count = 56, 
                        threads_per_core = 56, 
                        freq = 1.337, )
                    ]
            )
        else:
            return PhyCpu(
                vendor = '',
                brand = '',
                architecture = '',
                cores = [
                    cybee_sdk.api.models.cores_group.CoresGroup(
                        variant = '', 
                        cores_count = 56, 
                        threads_per_core = 56, 
                        freq = 1.337, )
                    ],
        )
        """

    def testPhyCpu(self):
        """Test PhyCpu"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
