# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.cmdb_api import CmdbApi


class TestCmdbApi(unittest.TestCase):
    """CmdbApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CmdbApi()

    def tearDown(self) -> None:
        pass

    def test_list_cmdb_items_cmdb_machines_get(self) -> None:
        """Test case for list_cmdb_items_cmdb_machines_get

        List Cmdb Items
        """
        pass

    def test_list_historical_cmdb_items_cmdb_machines_historical_get(self) -> None:
        """Test case for list_historical_cmdb_items_cmdb_machines_historical_get

        List Historical Cmdb Items
        """
        pass


if __name__ == "__main__":
    unittest.main()
