# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.restoration_info import RestorationInfo


class TestRestorationInfo(unittest.TestCase):
    """RestorationInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> RestorationInfo:
        """Test RestorationInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `RestorationInfo`
        """
        model = RestorationInfo()
        if include_optional:
            return RestorationInfo(
                status = cybee_sdk.api.models.restoration_status.RestorationStatus(
                    seconds_elapsed = 56, 
                    percent_done = 1.337, 
                    total_files = 56, 
                    files_restored = 56, 
                    total_bytes = 56, 
                    bytes_restored = 56, ),
                verbose_status = cybee_sdk.api.models.restore_verbose_status.RestoreVerboseStatus(
                    message_type = '', 
                    action = '', 
                    item = '', 
                    size = 56, ),
                restoration_error = cybee_sdk.api.models.restoration_error.RestorationError(
                    error = '', 
                    during = '', 
                    item = '', ),
                summary = cybee_sdk.api.models.restoration_summary.RestorationSummary(
                    seconds_elapsed = 56, 
                    total_files = 56, 
                    files_restored = 56, 
                    total_bytes = 56, 
                    bytes_restored = 56, ),
                unknown = '',
                other_error = '',
                restoration_ended = cybee_sdk.api.models.process_ended.ProcessEnded(),
                restoration_fully_finished = cybee_sdk.api.models.operation_fully_finished.OperationFullyFinished(),
                timestamp = ''
            )
        else:
            return RestorationInfo(
                timestamp = '',
        )
        """

    def testRestorationInfo(self):
        """Test RestorationInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
