# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Filesystem(BaseModel):
    """
    Filesystem
    """  # noqa: E501

    name: StrictStr
    filesystem: StrictStr
    mount_points: Optional[List[StrictStr]] = None
    total_size: StrictInt
    available_space: Optional[StrictInt] = None
    is_root: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = [
        "name",
        "filesystem",
        "mount_points",
        "total_size",
        "available_space",
        "is_root",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Filesystem from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if mount_points (nullable) is None
        # and model_fields_set contains the field
        if self.mount_points is None and "mount_points" in self.model_fields_set:
            _dict["mount_points"] = None

        # set to None if available_space (nullable) is None
        # and model_fields_set contains the field
        if self.available_space is None and "available_space" in self.model_fields_set:
            _dict["available_space"] = None

        # set to None if is_root (nullable) is None
        # and model_fields_set contains the field
        if self.is_root is None and "is_root" in self.model_fields_set:
            _dict["is_root"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Filesystem from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "filesystem": obj.get("filesystem"),
                "mount_points": obj.get("mount_points"),
                "total_size": obj.get("total_size"),
                "available_space": obj.get("available_space"),
                "is_root": obj.get("is_root"),
            }
        )
        return _obj
