# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.backup_info import BackupInfo


class TestBackupInfo(unittest.TestCase):
    """BackupInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> BackupInfo:
        """Test BackupInfo
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `BackupInfo`
        """
        model = BackupInfo()
        if include_optional:
            return BackupInfo(
                status = cybee_sdk.api.models.backup_status.BackupStatus(
                    seconds_elapsed = 56, 
                    seconds_remaining = 56, 
                    percent_done = 1.337, 
                    total_files = 56, 
                    files_done = 56, 
                    total_bytes = 56, 
                    bytes_done = 56, 
                    error_count = 56, 
                    current_files = [
                        ''
                        ], ),
                restic_error = cybee_sdk.api.models.backup_error.BackupError(
                    error = '', 
                    during = '', 
                    item = '', ),
                restic_fatal_error = cybee_sdk.api.models.backup_fatal_error.BackupFatalError(
                    code = 56, 
                    message = '', ),
                verbose_status = cybee_sdk.api.models.backup_verbose_status.BackupVerboseStatus(
                    action = '', 
                    item = '', 
                    duration = 1.337, 
                    data_size = 56, 
                    data_size_in_repo = 56, 
                    metadata_size = 56, 
                    metadata_size_in_repo = 56, 
                    total_files = 56, ),
                summary = cybee_sdk.api.models.backup_summary.BackupSummary(
                    files_new = 0.0, 
                    files_changed = 0.0, 
                    files_unmodified = 0.0, 
                    dirs_new = 0.0, 
                    dirs_changed = 0.0, 
                    dirs_unmodified = 0.0, 
                    data_blobs = 0.0, 
                    tree_blobs = 0.0, 
                    data_added = 0.0, 
                    data_added_packed = 0.0, 
                    total_files_processed = 0.0, 
                    total_bytes_processed = 0.0, 
                    total_duration = 1.337, 
                    snapshot_id = '', ),
                unknown = '',
                other_error = '',
                backup_ended = cybee_sdk.api.models.process_ended.ProcessEnded(),
                backup_fully_finished = cybee_sdk.api.models.operation_fully_finished.OperationFullyFinished(),
                timestamp = '',
                backup_paths = [
                    ''
                    ]
            )
        else:
            return BackupInfo(
                timestamp = '',
        )
        """

    def testBackupInfo(self):
        """Test BackupInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
