# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.identity_api import IdentityApi


class TestIdentityApi(unittest.TestCase):
    """IdentityApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IdentityApi()

    def tearDown(self) -> None:
        pass

    def test_create_api_key_identity_keys_post(self) -> None:
        """Test case for create_api_key_identity_keys_post

        Create Api Key
        """
        pass

    def test_list_all_api_keys_identity_keys_get(self) -> None:
        """Test case for list_all_api_keys_identity_keys_get

        List All Api Keys
        """
        pass

    def test_list_all_organization_identity_organization_get(self) -> None:
        """Test case for list_all_organization_identity_organization_get

        List All Organization
        """
        pass

    def test_revoke_api_key_identity_keys_key_id_delete(self) -> None:
        """Test case for revoke_api_key_identity_keys_key_id_delete

        Revoke Api Key
        """
        pass


if __name__ == "__main__":
    unittest.main()
