# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.api.storage_repository_api import StorageRepositoryApi


class TestStorageRepositoryApi(unittest.TestCase):
    """StorageRepositoryApi unit test stubs"""

    def setUp(self) -> None:
        self.api = StorageRepositoryApi()

    def tearDown(self) -> None:
        pass

    def test_create_repository_storage_repository_post(self) -> None:
        """Test case for create_repository_storage_repository_post

        Create Repository
        """
        pass

    def test_delete_repository_storage_repository_repository_id_delete(self) -> None:
        """Test case for delete_repository_storage_repository_repository_id_delete

        Delete Repository
        """
        pass

    def test_execute_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_execute_post(
        self,
    ) -> None:
        """Test case for execute_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_execute_post

        Execute Repository Maintenance
        """
        pass

    def test_get_repository_maintenance_storage_repository_repository_id_maintenance_get(self) -> None:
        """Test case for get_repository_maintenance_storage_repository_repository_id_maintenance_get

        Get Repository Maintenance
        """
        pass

    def test_get_repository_storage_repository_repository_id_get(self) -> None:
        """Test case for get_repository_storage_repository_repository_id_get

        Get Repository
        """
        pass

    def test_list_repository_checks_storage_repository_check_history_get(self) -> None:
        """Test case for list_repository_checks_storage_repository_check_history_get

        List Repository Checks
        """
        pass

    def test_list_repository_prunes_storage_repository_prune_history_get(self) -> None:
        """Test case for list_repository_prunes_storage_repository_prune_history_get

        List Repository Prunes
        """
        pass

    def test_list_repository_stats_storage_repository_stats_get(self) -> None:
        """Test case for list_repository_stats_storage_repository_stats_get

        List Repository Stats
        """
        pass

    def test_list_repository_storage_repository_get(self) -> None:
        """Test case for list_repository_storage_repository_get

        List Repository
        """
        pass

    def test_set_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_post(
        self,
    ) -> None:
        """Test case for set_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_post

        Set Repository Maintenance
        """
        pass

    def test_unset_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_delete(
        self,
    ) -> None:
        """Test case for unset_repository_maintenance_storage_repository_repository_id_maintenance_maintenance_type_delete

        Unset Repository Maintenance
        """
        pass

    def test_update_repository_storage_repository_repository_id_patch(self) -> None:
        """Test case for update_repository_storage_repository_repository_id_patch

        Update Repository
        """
        pass


if __name__ == "__main__":
    unittest.main()
