# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from cybee_sdk.api.models.scheduling import Scheduling


class TestScheduling(unittest.TestCase):
    """Scheduling unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Scheduling:
        """Test Scheduling
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `Scheduling`
        """
        model = Scheduling()
        if include_optional:
            return Scheduling(
                id = '',
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                enabled = True,
                cron_calendar = cybee_sdk.api.models.cron_calendar.CronCalendar(
                    minute = null, 
                    hour = null, 
                    day_of_month = null, 
                    month_of_year = null, 
                    day_of_week = null, 
                    timezone = null, ),
                linked_plans = [
                    cybee_sdk.api.models.scheduling_linked_plans.SchedulingLinkedPlans(
                        id = '', 
                        type = null, )
                    ]
            )
        else:
            return Scheduling(
                id = '',
                timestamps = cybee_sdk.api.models.time_stamps.TimeStamps(
                    created_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                    updated_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                cron_calendar = cybee_sdk.api.models.cron_calendar.CronCalendar(
                    minute = null, 
                    hour = null, 
                    day_of_month = null, 
                    month_of_year = null, 
                    day_of_week = null, 
                    timezone = null, ),
        )
        """

    def testScheduling(self):
        """Test Scheduling"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
