# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool
from typing import Any, ClassVar, Dict, List, Optional
from uuid import UUID
from cybee_sdk.api.models.cron_calendar import CronCalendar
from cybee_sdk.api.models.scheduling_linked_plans import SchedulingLinkedPlans
from cybee_sdk.api.models.time_stamps import TimeStamps
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class Scheduling(BaseModel):
    """
    Scheduling
    """  # noqa: E501

    id: UUID
    timestamps: TimeStamps
    enabled: Optional[StrictBool] = False
    cron_calendar: CronCalendar
    linked_plans: Optional[List[SchedulingLinkedPlans]] = None
    __properties: ClassVar[List[str]] = ["id", "timestamps", "enabled", "cron_calendar", "linked_plans"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Scheduling from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of timestamps
        if self.timestamps:
            _dict["timestamps"] = self.timestamps.to_dict()
        # override the default output from pydantic by calling `to_dict()` of cron_calendar
        if self.cron_calendar:
            _dict["cron_calendar"] = self.cron_calendar.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in linked_plans (list)
        _items = []
        if self.linked_plans:
            for _item_linked_plans in self.linked_plans:
                if _item_linked_plans:
                    _items.append(_item_linked_plans.to_dict())
            _dict["linked_plans"] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Scheduling from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "id": obj.get("id"),
                "timestamps": TimeStamps.from_dict(obj["timestamps"]) if obj.get("timestamps") is not None else None,
                "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
                "cron_calendar": CronCalendar.from_dict(obj["cron_calendar"])
                if obj.get("cron_calendar") is not None
                else None,
                "linked_plans": [SchedulingLinkedPlans.from_dict(_item) for _item in obj["linked_plans"]]
                if obj.get("linked_plans") is not None
                else None,
            }
        )
        return _obj
