# coding: utf-8

"""
Cybee API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 0.42.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python


class RetentionSettings(BaseModel):
    """
    RetentionSettings
    """  # noqa: E501

    keep_last: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_hourly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_daily: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_weekly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_monthly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_yearly: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_hourly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_daily_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_weekly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_monthly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    keep_within_yearly_as_secs: Optional[Annotated[int, Field(lt=2147483647, strict=True, ge=0)]] = None
    __properties: ClassVar[List[str]] = [
        "keep_last",
        "keep_hourly",
        "keep_daily",
        "keep_weekly",
        "keep_monthly",
        "keep_yearly",
        "keep_within_as_secs",
        "keep_within_hourly_as_secs",
        "keep_within_daily_as_secs",
        "keep_within_weekly_as_secs",
        "keep_within_monthly_as_secs",
        "keep_within_yearly_as_secs",
    ]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RetentionSettings from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if keep_last (nullable) is None
        # and model_fields_set contains the field
        if self.keep_last is None and "keep_last" in self.model_fields_set:
            _dict["keep_last"] = None

        # set to None if keep_hourly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_hourly is None and "keep_hourly" in self.model_fields_set:
            _dict["keep_hourly"] = None

        # set to None if keep_daily (nullable) is None
        # and model_fields_set contains the field
        if self.keep_daily is None and "keep_daily" in self.model_fields_set:
            _dict["keep_daily"] = None

        # set to None if keep_weekly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_weekly is None and "keep_weekly" in self.model_fields_set:
            _dict["keep_weekly"] = None

        # set to None if keep_monthly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_monthly is None and "keep_monthly" in self.model_fields_set:
            _dict["keep_monthly"] = None

        # set to None if keep_yearly (nullable) is None
        # and model_fields_set contains the field
        if self.keep_yearly is None and "keep_yearly" in self.model_fields_set:
            _dict["keep_yearly"] = None

        # set to None if keep_within_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_as_secs is None and "keep_within_as_secs" in self.model_fields_set:
            _dict["keep_within_as_secs"] = None

        # set to None if keep_within_hourly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_hourly_as_secs is None and "keep_within_hourly_as_secs" in self.model_fields_set:
            _dict["keep_within_hourly_as_secs"] = None

        # set to None if keep_within_daily_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_daily_as_secs is None and "keep_within_daily_as_secs" in self.model_fields_set:
            _dict["keep_within_daily_as_secs"] = None

        # set to None if keep_within_weekly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_weekly_as_secs is None and "keep_within_weekly_as_secs" in self.model_fields_set:
            _dict["keep_within_weekly_as_secs"] = None

        # set to None if keep_within_monthly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_monthly_as_secs is None and "keep_within_monthly_as_secs" in self.model_fields_set:
            _dict["keep_within_monthly_as_secs"] = None

        # set to None if keep_within_yearly_as_secs (nullable) is None
        # and model_fields_set contains the field
        if self.keep_within_yearly_as_secs is None and "keep_within_yearly_as_secs" in self.model_fields_set:
            _dict["keep_within_yearly_as_secs"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RetentionSettings from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "keep_last": obj.get("keep_last"),
                "keep_hourly": obj.get("keep_hourly"),
                "keep_daily": obj.get("keep_daily"),
                "keep_weekly": obj.get("keep_weekly"),
                "keep_monthly": obj.get("keep_monthly"),
                "keep_yearly": obj.get("keep_yearly"),
                "keep_within_as_secs": obj.get("keep_within_as_secs"),
                "keep_within_hourly_as_secs": obj.get("keep_within_hourly_as_secs"),
                "keep_within_daily_as_secs": obj.get("keep_within_daily_as_secs"),
                "keep_within_weekly_as_secs": obj.get("keep_within_weekly_as_secs"),
                "keep_within_monthly_as_secs": obj.get("keep_within_monthly_as_secs"),
                "keep_within_yearly_as_secs": obj.get("keep_within_yearly_as_secs"),
            }
        )
        return _obj
